@@ -3,6 +3,9 @@ package rpmdb
 import (
 	"testing"
 
+	"github.com/google/uuid"
+	"github.com/stretchr/testify/require"
+
 	"github.com/stretchr/testify/assert"
 
 	"github.com/anchore/grype/grype/distro"
@@ -27,11 +30,15 @@ func TestMatcherRpmdb(t *testing.T) {
 		{
 			name: "Rpmdb Match matches by direct and by source indirection",
 			p: pkg.Package{
+				ID:      pkg.ID(uuid.NewString()),
 				Name:    "neutron-libs",
 				Version: "7.1.3-6",
 				Type:    syftPkg.RpmPkg,
-				Metadata: pkg.RpmdbMetadata{
-					SourceRpm: "neutron-7.1.3-6.el8.src.rpm",
+				Upstreams: []pkg.UpstreamPackage{
+					{
+						Name:    "neutron",
+						Version: "7.1.3-6.el8",
+					},
 				},
 			},
 			setup: func() (vulnerability.Provider, *distro.Distro, Matcher) {
@@ -54,11 +61,15 @@ func TestMatcherRpmdb(t *testing.T) {
 		{
 			name: "Rpmdb Match matches by direct and ignores the source rpm when the package names are the same",
 			p: pkg.Package{
+				ID:      pkg.ID(uuid.NewString()),
 				Name:    "neutron",
 				Version: "7.1.3-6",
 				Type:    syftPkg.RpmPkg,
-				Metadata: pkg.RpmdbMetadata{
-					SourceRpm: "neutron-7.1.3-6.el8.src.rpm",
+				Upstreams: []pkg.UpstreamPackage{
+					{
+						Name:    "neutron",
+						Version: "7.1.3-6.el8",
+					},
 				},
 			},
 			setup: func() (vulnerability.Provider, *distro.Distro, Matcher) {
@@ -80,11 +91,15 @@ func TestMatcherRpmdb(t *testing.T) {
 			// Regression against https://github.com/anchore/grype/issues/376
 			name: "Rpmdb Match matches by direct and by source indirection when the SourceRpm version is desynced from package version",
 			p: pkg.Package{
+				ID:      pkg.ID(uuid.NewString()),
 				Name:    "neutron-libs",
 				Version: "7.1.3-6",
 				Type:    syftPkg.RpmPkg,
-				Metadata: pkg.RpmdbMetadata{
-					SourceRpm: "neutron-17.16.3-229.el8.src.rpm",
+				Upstreams: []pkg.UpstreamPackage{
+					{
+						Name:    "neutron",
+						Version: "17.16.3-229.el8",
+					},
 				},
 			},
 			setup: func() (vulnerability.Provider, *distro.Distro, Matcher) {
@@ -107,12 +122,18 @@ func TestMatcherRpmdb(t *testing.T) {
 			// Regression: https://github.com/anchore/grype/issues/437
 			name: "Rpmdb Match should not occur due to source match even though source has no epoch",
 			p: pkg.Package{
+				ID:      pkg.ID(uuid.NewString()),
 				Name:    "perl-Errno",
 				Version: "0:1.28-419.el8_4.1",
 				Type:    syftPkg.RpmPkg,
 				Metadata: pkg.RpmdbMetadata{
-					SourceRpm: "perl-5.26.3-419.el8_4.1.src.rpm",
-					Epoch:     intRef(0),
+					Epoch: intRef(0),
+				},
+				Upstreams: []pkg.UpstreamPackage{
+					{
+						Name:    "perl",
+						Version: "5.26.3-419.el8_4.1",
+					},
 				},
 			},
 			setup: func() (vulnerability.Provider, *distro.Distro, Matcher) {
@@ -135,6 +156,7 @@ func TestMatcherRpmdb(t *testing.T) {
 		{
 			name: "package without epoch is assumed to be 0 - compared against vuln with NO epoch (direct match only)",
 			p: pkg.Package{
+				ID:       pkg.ID(uuid.NewString()),
 				Name:     "perl-Errno",
 				Version:  "1.28-419.el8_4.1",
 				Type:     syftPkg.RpmPkg,
@@ -158,6 +180,7 @@ func TestMatcherRpmdb(t *testing.T) {
 		{
 			name: "package without epoch is assumed to be 0 - compared against vuln WITH epoch (direct match only)",
 			p: pkg.Package{
+				ID:       pkg.ID(uuid.NewString()),
 				Name:     "perl-Errno",
 				Version:  "1.28-419.el8_4.1",
 				Type:     syftPkg.RpmPkg,
@@ -181,6 +204,7 @@ func TestMatcherRpmdb(t *testing.T) {
 		{
 			name: "package WITH epoch - compared against vuln with NO epoch (direct match only)",
 			p: pkg.Package{
+				ID:       pkg.ID(uuid.NewString()),
 				Name:     "perl-Errno",
 				Version:  "2:1.28-419.el8_4.1",
 				Type:     syftPkg.RpmPkg,
@@ -204,6 +228,7 @@ func TestMatcherRpmdb(t *testing.T) {
 		{
 			name: "package WITH epoch - compared against vuln WITH epoch (direct match only)",
 			p: pkg.Package{
+				ID:       pkg.ID(uuid.NewString()),
 				Name:     "perl-Errno",
 				Version:  "2:1.28-419.el8_4.1",
 				Type:     syftPkg.RpmPkg,
@@ -239,11 +264,14 @@ func TestMatcherRpmdb(t *testing.T) {
 					t.Errorf("return unkown match CVE: %s", a.Vulnerability.ID)
 					continue
 				} else {
-					assert.Equal(t, val, a.Type)
+					require.NotEmpty(t, a.Details)
+					for _, de := range a.Details {
+						assert.Equal(t, val, de.Type)
+					}
 				}
 
 				assert.Equal(t, test.p.Name, a.Package.Name, "failed to capture original package name")
-				for _, detail := range a.MatchDetails {
+				for _, detail := range a.Details {
 					assert.Equal(t, matcher.Type(), detail.Matcher, "failed to capture matcher type")
 				}
 			}
@@ -255,66 +283,6 @@ func TestMatcherRpmdb(t *testing.T) {
 	}
 }
 
-func Test_getNameAndELVersion(t *testing.T) {
-	epoch := 1
-	tests := []struct {
-		name            string
-		metadata        pkg.RpmdbMetadata
-		expectedName    string
-		expectedVersion string
-	}{
-		{
-			name: "sqlite-3.26.0-6.el8.src.rpm",
-			metadata: pkg.RpmdbMetadata{
-				SourceRpm: "sqlite-3.26.0-6.el8.src.rpm",
-			},
-			expectedName:    "sqlite",
-			expectedVersion: "3.26.0-6.el8",
-		},
-		{
-			name: "util-linux-ng-2.17.2-12.28.el6_9.src.rpm",
-			metadata: pkg.RpmdbMetadata{
-				SourceRpm: "util-linux-ng-2.17.2-12.28.el6_9.src.rpm",
-			},
-			expectedName:    "util-linux-ng",
-			expectedVersion: "2.17.2-12.28.el6_9",
-		},
-		{
-			name: "util-linux-ng-2.17.2-12.28.el6_9.2.src.rpm",
-			metadata: pkg.RpmdbMetadata{
-				SourceRpm: "util-linux-ng-2.17.2-12.28.el6_9.2.src.rpm",
-			},
-			expectedName:    "util-linux-ng",
-			expectedVersion: "2.17.2-12.28.el6_9.2",
-		},
-		{
-			name: "epoch 1 + sqlite-3.26.0-6.el8.src.rpm",
-			metadata: pkg.RpmdbMetadata{
-				SourceRpm: "sqlite-3.26.0-6.el8.src.rpm",
-				Epoch:     &epoch,
-			},
-			expectedName:    "sqlite",
-			expectedVersion: "3.26.0-6.el8",
-		},
-		{
-			name: "sqlite-bin-3.26.0-6.el8.src.rpm",
-			metadata: pkg.RpmdbMetadata{
-				SourceRpm: "sqlite-1.26.0-6.el8.src.rpm",
-				Epoch:     &epoch,
-			},
-			expectedName:    "sqlite",
-			expectedVersion: "1.26.0-6.el8",
-		},
-	}
-	for _, test := range tests {
-		t.Run(test.name, func(t *testing.T) {
-			actualName, actualVersion := getNameAndELVersion(test.metadata)
-			assert.Equal(t, test.expectedName, actualName)
-			assert.Equal(t, test.expectedVersion, actualVersion)
-		})
-	}
-}
-
 func Test_addZeroEpicIfApplicable(t *testing.T) {
 	tests := []struct {
 		version  string
